<?php

global $priority_list;
$priority_list = array (

'6'	=>	'Unverzüglich',
'5'	=>	'Dringend',
'4'	=>	'Eilig',
'3'	=>	'Hoch',
'2'	=>	'Normal',
'1'	=>	'Niedrig',

);
?>
